# Kupala Framework

A modern web framework for Python.

![PyPI](https://img.shields.io/pypi/v/kupala)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/alex-oleshkevich/kupala/Lint)
![GitHub](https://img.shields.io/github/license/alex-oleshkevich/kupala)
![Libraries.io dependency status for latest release](https://img.shields.io/librariesio/release/pypi/kupala)
![PyPI - Downloads](https://img.shields.io/pypi/dm/kupala)
![GitHub Release Date](https://img.shields.io/github/release-date/alex-oleshkevich/kupala)
![Lines of code](https://img.shields.io/tokei/lines/github/alex-oleshkevich/kupala)

## Installation

Install `kupala` using PIP or poetry:

```bash
pip install kupala
# or
poetry add kupala
```

## Features

-   TODO

## Quick start

See example application in `examples/` directory of this repository.
